# neuralnet-pytorch
A high level framework for general purpose neural networks in Pytorch.

## Requirements

[Pytorch](http://deeplearning.net/software/theano/)

[Scipy](https://www.scipy.org/install.html), [Numpy+mkl](http://www.lfd.uci.edu/~gohlke/pythonlibs/#numpy), [Matplotlib](https://matplotlib.org/)

## Installation

```
pip install --upgrade neuralnet-pytorch
```

To install the Git version

```
pip install git+git://github.com/justanhduc/neuralnet-pytorch.git@master
```


## Usages
To create a new model, simply make a new model class and inherit from Model in model.py
